exceptiontools.MissingPitchError
================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
